local VERSION = tonumber(("$Revision: 43802 $"):match("%d+"))

local QuestsFu = QuestsFu
local QuestsFu_PartyNotify = QuestsFu:NewModule("PartyNotify", "AceEvent-2.0", "AceConsole-2.0")
if QuestsFu.revision < VERSION then
	QuestsFu.version = "r" .. VERSION
	QuestsFu.revision = VERSION
	QuestsFu.date = ("$Date: 2007-07-14 18:56:30 -0400 (Sat, 14 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end

local L = AceLibrary("AceLocale-2.2"):new("QuestsFu_PartyNotify")

QuestsFu_PartyNotify.lname = L["Party status"]
QuestsFu_PartyNotify.desc = L["Report on party quest status"]

function QuestsFu_PartyNotify:OnInitialize()
	self.db = QuestsFu:AcquireDBNamespace("PartyNotify")
	QuestsFu:RegisterDefaults("PartyNotify", "profile", {
		message = true,
		chat = false,
	})
	self.menu = {
		name = L["Party status"],
		desc = L["Report on party quest status"],
		type = "group",
		args = {
			message = {
				type = "toggle", name = L["Messageframe"],
				desc = L["Show in the messageframe (like normal quest notifications)"],
				get = function() return self.db.profile.message end,
				set = function(t) self.db.profile.message = t end,
			},
			chat = {
				type = "toggle", name = L["Chat"],
				desc = L["Show in the chatframe"],
				get = function() return self.db.profile.chat end,
				set = function(t) self.db.profile.chat = t end,
			},
		},
	}
end

function QuestsFu_PartyNotify:OnEnable()
	self:RegisterEvent("Quixote_Party_Leaderboard_Update")
	self:RegisterEvent("Quixote_Party_Quest_Complete")
end

function QuestsFu_PartyNotify:Notification(message)
	if self.db.profile.message then
		UIErrorsFrame:AddMessage(message, 1.0, 1.0, 0.0, 1.0)
	end
	if self.db.profile.chat then
		self:Print(message)
	end
end

function QuestsFu_PartyNotify:Quixote_Party_Quest_Complete(sender, title)
	self:Notification(("(%s:%s): Complete"):format(sender, title))
end

function QuestsFu_PartyNotify:Quixote_Party_Leaderboard_Update(sender, title, description, numHad, numGot, numNeeded)
	local message
	if numGot == numNeeded then
		message = ("(%s:%s) %s: %s"):format(sender,title,description,L["completed"])
	else
		message = ("(%s:%s) %s: %d/%d"):format(sender,title,description,numGot,numNeeded)
	end
	self:Notification(message)
end
